.. -*- mode: rst -*-

|Travis|_ |AppVeyor|_ |Codecov|_ |CircleCI|_ |ReadTheDocs|_

.. |Travis| image:: https://travis-ci.org/nimh-mbdu/sklearn-lmer.svg?branch=master
.. _Travis: https://travis-ci.org/nimh-mbdu/sklearn-lmer

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/pifxyfnev94kbej4/branch/master?svg=true
.. _AppVeyor: https://ci.appveyor.com/project/Shotgunosine/sklearn-lmer/branch/master

.. |Codecov| image:: https://codecov.io/gh/nimh-mbdu/sklearn-lmer/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/nimh-mbdu/sklearn-lmer
.. _Codecov: https://codecov.io/gh/nimh-mbdu/sklearn-lmer

.. |CircleCI| image:: https://circleci.com/gh/nimh-mbdu/sklearn-lmer.svg?style=shield&circle-token=:circle-token
.. _CircleCI: https://circleci.com/gh/nimh-mbdu/sklearn-lmer/tree/master

.. |ReadTheDocs| image:: https://readthedocs.org/projects/sklearn-lmer/badge/?version=latest
.. _ReadTheDocs: https://sklearn-lmer.readthedocs.io/en/latest/?badge=latest

project-template - A template for scikit-learn contributions
============================================================

.. _scikit-learn: https://scikit-learn.org

**project-template** is a template project for scikit-learn_ compatible
extensions.

It aids development of estimators that can be used in scikit-learn pipelines
and (hyper)parameter search, while facilitating testing (including some API
compliance), documentation, open source development, packaging, and continuous
integration.

.. _documentation: https://sklearn-template.readthedocs.io/en/latest/quick_start.html

Refer to the documentation_ to modify the template for your own scikit-learn
contribution.

*Thank you for cleanly contributing to the scikit-learn ecosystem!*
